Index: /trunk/PS-IPP-Config/lib/PS/IPP/Config.pm
===================================================================
--- /trunk/PS-IPP-Config/lib/PS/IPP/Config.pm	(revision 12829)
+++ /trunk/PS-IPP-Config/lib/PS/IPP/Config.pm	(revision 12830)
@@ -1,5 +1,5 @@
 # Copyright (c) 2006  Paul Price, Joshua Hoblitt
 #
-# $Id: Config.pm,v 1.34 2007-04-11 01:58:02 eugene Exp $
+# $Id: Config.pm,v 1.35 2007-04-13 03:15:04 price Exp $
 
 package PS::IPP::Config;
@@ -27,4 +27,6 @@
     $PS_EXIT_DATA_ERROR
     $PS_EXIT_TIMEOUT_ERROR
+    metadataLookupStr
+    metadataLookupMD
 );
 
@@ -70,5 +72,5 @@
     my $mdc = $parser->parse( join '', @contents); # The parsed metadata config
 
-    my $path = _interpolate_env(_mdLookupStr($mdc, 'PATH')); # The path
+    my $path = _interpolate_env(metadataLookupStr($mdc, 'PATH')); # The path
     unless (defined $path) {
 	carp "PATH is not set in $name\n";
@@ -101,6 +103,6 @@
     }
 
-    my $camera_list = _mdLookupMD($self->{_ipprc}, 'CAMERAS'); # List of cameras
-    my $filename = _mdLookupStr($camera_list, $name); # Filename of camera configuration
+    my $camera_list = metadataLookupMD($self->{_ipprc}, 'CAMERAS'); # List of cameras
+    my $filename = metadataLookupStr($camera_list, $name); # Filename of camera configuration
     unless (defined $filename) {
 	carp "Unable to find configuration file for camera $name\n";
@@ -165,6 +167,6 @@
     }
 
-    my $path_list = _mdLookupMD($self->{_ipprc}, 'DATAPATH'); # List of paths
-    my $pathname = _mdLookupStr($path_list, $name); # Path of interest
+    my $path_list = metadataLookupMD($self->{_ipprc}, 'DATAPATH'); # List of paths
+    my $pathname = metadataLookupStr($path_list, $name); # Path of interest
     unless (defined $pathname) {
 	carp "Unable to find camera configuration file $pathname\n" ;
@@ -229,5 +231,5 @@
     pop @dirs;			# Get rid of filename
 
-    my $path_list = _mdLookupMD($self->{_ipprc}, 'DATAPATH'); # List of paths
+    my $path_list = metadataLookupMD($self->{_ipprc}, 'DATAPATH'); # List of paths
     my $best_path;
     my $best_name;
@@ -285,5 +287,5 @@
     }
 
-    my $rejection = _mdLookupMD($camera, 'REJECTION');	# Rejection list
+    my $rejection = metadataLookupMD($camera, 'REJECTION');	# Rejection list
     unless (defined $rejection) {
 	carp "Can't find REJECTION list in camera configuration.\n";
@@ -346,5 +348,5 @@
     }
 
-    my $filerules = _mdLookupMD($camera, 'FILERULES');	# File rules
+    my $filerules = metadataLookupMD($camera, 'FILERULES');	# File rules
     unless (defined $filerules) {
 	carp "Can't find FILERULES list in camera configuration.\n";
@@ -358,5 +360,5 @@
     }
 
-    my $filename = _mdLookupStr($file, "FILENAME.RULE"); # File name
+    my $filename = metadataLookupStr($file, "FILENAME.RULE"); # File name
     unless (defined $filename) {
 	carp "Can't find FILENAME.RULE for $name within FILERULES in camera configuration.\n";
@@ -395,5 +397,5 @@
 ##      }
 ##  
 ##      my $extname_rules = _mdLookupMD($camera, 'EXTNAME.RULES');	# File rules
 ##      unless (defined $extname_fules) {
 ##  	carp "Can't find EXTNAME.RULES in camera configuration.\n";
@@ -401,5 +403,5 @@
 ##      }
 ##  
 ##      my $extname = _mdLookupStr($file, $name); # File name
 ##      unless (defined $extname) {
 ##  	carp "Can't find $name within EXTNAME.RULES in camera configuration.\n";
@@ -434,5 +436,5 @@
     }
 
-    my $dir = _mdLookupStr($camera, "DVO.CAMERADIR"); # Directory of interest
+    my $dir = metadataLookupStr($camera, "DVO.CAMERADIR"); # Directory of interest
     unless (defined $dir) {
 	carp "Can't find DVO.CAMERADIR in camera configuration.\n";
@@ -463,5 +465,5 @@
 
 # Lookup the metadata, checking the type is STR
-sub _mdLookupStr
+sub metadataLookupStr
 {
     my $mdc = shift;		# Metadata config to look up
@@ -486,5 +488,5 @@
 
 # Lookup the metadata, checking the type is MD
-sub _mdLookupMD
+sub metadataLookupMD
 {
     my $mdc = shift;		# Metadata config to look up
@@ -507,5 +509,4 @@
     return undef;
 }
-
 
 # Lookup the metadata, checking the type is MD; may be redirection
@@ -395,5 +397,5 @@
 ##      }
 ##  
-##      my $extname_rules = _mdLookupMD($camera, 'EXTNAME.RULES');	# File rules
+##      my $extname_rules = metadataLookupMD($camera, 'EXTNAME.RULES');	# File rules
 ##      unless (defined $extname_fules) {
 ##  	carp "Can't find EXTNAME.RULES in camera configuration.\n";
@@ -401,5 +403,5 @@
 ##      }
 ##  
-##      my $extname = _mdLookupStr($file, $name); # File name
+##      my $extname = metadataLookupStr($file, $name); # File name
 ##      unless (defined $extname) {
 ##  	carp "Can't find $name within EXTNAME.RULES in camera configuration.\n";
